@@ -10,10 +10,10 @@ from collections import UserDict
 from collections.abc import MutableMapping
 from datetime import datetime
 from logging import getLogger
-from typing import Callable, Iterable, Iterator, Tuple, Union
+from typing import Callable, Iterable, Iterator, Optional, Tuple, Union
 
 from ..cache_control import ExpirationTime
-from ..cache_keys import create_key, remove_ignored_params, remove_ignored_url_params
+from ..cache_keys import create_key, redact_response
 from ..models import AnyRequest, AnyResponse, CachedResponse
 from ..serializers import init_serializer
 
@@ -44,7 +44,7 @@ class BaseCache:
 
     def __init__(
         self,
-        *args,
+        cache_name: str = 'http_cache',
         match_headers: Union[Iterable[str], bool] = False,
         ignored_parameters: Iterable[str] = None,
         key_fn: KEY_FN = None,
@@ -52,9 +52,9 @@ class BaseCache:
     ):
         self.responses: BaseStorage = DictStorage()
         self.redirects: BaseStorage = DictStorage()
+        self.cache_name = cache_name
         self.ignored_parameters = ignored_parameters
         self.key_fn = key_fn or create_key
-        self.name: str = kwargs.get('cache_name', '')
         self.match_headers = match_headers or kwargs.pop('include_get_headers', False)
 
     @property
@@ -63,7 +63,7 @@ class BaseCache:
         for response in self.values():
             yield response.url
 
-    def get_response(self, key: str, default=None) -> CachedResponse:
+    def get_response(self, key: str, default=None) -> Optional[CachedResponse]:
         """Retrieve a response from the cache, if it exists
 
         Args:
@@ -71,11 +71,10 @@ class BaseCache:
             default: Value to return if `key` is not in the cache
         """
         try:
-            if key not in self.responses:
-                key = self.redirects[key]
-            response = self.responses[key]
-            response.cache_key = key  # Set cache key here, since it's not serialized
-            response.reset()  # In case response was in memory and content has already been read
+            response = self.responses.get(key)
+            if response is None:  # Note: bool(requests.Response) is False if status > 400
+                response = self.responses[self.redirects[key]]
+            response.cache_key = key
             return response
         except KeyError:
             return default
@@ -89,13 +88,12 @@ class BaseCache:
 
         Args:
             cache_key: Cache key for this response; will otherwise be generated based on request
-            response: response to save
-            expire_after: Time in seconds until this cache item should expire
+            response: Response to save
+            expires: Absolute expiration time for this response
         """
         cache_key = cache_key or self.create_key(response.request)
         cached_response = CachedResponse.from_response(response, expires=expires)
-        cached_response.url = remove_ignored_url_params(response.url, self.ignored_parameters)
-        cached_response.request = remove_ignored_params(cached_response.request, self.ignored_parameters)
+        cached_response = redact_response(cached_response, self.ignored_parameters)
         self.responses[cache_key] = cached_response
         for r in response.history:
             self.redirects[self.create_key(r.request)] = cache_key
@@ -231,13 +229,10 @@ class BaseCache:
             self.bulk_delete(invalid_keys)
 
     def __str__(self):
-        """Show a count of total **rows** currently stored in the backend. For performance reasons,
-        this does not check for invalid or expired responses.
-        """
-        return f'Total rows: {len(self.responses)} responses, {len(self.redirects)} redirects'
+        return f'<{self.__class__.__name__}(name={self.cache_name})>'
 
     def __repr__(self):
-        return f'<{self.__class__.__name__}(name={self.name})>'
+        return str(self)
 
 
 class BaseStorage(MutableMapping, ABC):
@@ -263,9 +258,17 @@ class BaseStorage(MutableMapping, ABC):
         serializer=None,
         **kwargs,
     ):
-        self.serializer = init_serializer(serializer, **kwargs)
+        self._serializer = init_serializer(serializer, **kwargs)
         logger.debug(f'Initializing {type(self).__name__} with serializer: {self.serializer}')
 
+    @property
+    def serializer(self):
+        return self._serializer
+
+    @serializer.setter
+    def serializer(self, value):
+        self._serializer = init_serializer(value)
+
     def bulk_delete(self, keys: Iterable[str]):
         """Delete multiple keys from the cache, without raising errors for missing keys. This is a
         naive implementation that subclasses should override with a more efficient backend-specific
@@ -290,3 +293,16 @@ class DictStorage(UserDict, BaseStorage):
         is recommended instead.
 
     """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._serializer = None
+
+    def __getitem__(self, key):
+        """An additional step is needed here for response data. Since the original response object
+        is still in memory, its content has already been read and needs to be reset.
+        """
+        item = super().__getitem__(key)
+        if getattr(item, 'raw', None):
+            item.raw.reset()
+        return item
