@@ -1,7 +1,11 @@
 """Utilities for patching ``requests``.
 
-.. warning:: These functions are not thread-safe. Use :py:class:`.CachedSession` directly if you
-    want to use caching in a multi-threaded environment.
+.. warning:: These functions are not thread-safe. Use :py:class:`.CachedSession` if you want to use
+    caching in a multi-threaded environment.
+
+.. automodsumm:: requests_cache.patcher
+   :functions-only:
+   :nosignatures:
 """
 from contextlib import contextmanager
 from logging import getLogger
@@ -9,7 +13,7 @@ from typing import Callable, Dict, Iterable, Optional, Type
 
 import requests
 
-from .backends import BackendSpecifier, BaseCache
+from .backends import BackendSpecifier, BaseCache, init_backend
 from .cache_control import ExpirationTime
 from .session import CachedSession, OriginalSession
 
@@ -24,7 +28,7 @@ def install_cache(
     allowable_codes: Iterable[int] = (200,),
     allowable_methods: Iterable['str'] = ('GET', 'HEAD'),
     filter_fn: Callable = None,
-    old_data_on_error: bool = False,
+    stale_if_error: bool = False,
     session_factory: Type[OriginalSession] = CachedSession,
     **kwargs,
 ):
@@ -41,6 +45,7 @@ def install_cache(
         session_factory: Session class to use. It must inherit from either
             :py:class:`.CachedSession` or :py:class:`.CacheMixin`
     """
+    backend = init_backend(cache_name, backend, **kwargs)
 
     class _ConfiguredCachedSession(session_factory):  # type: ignore  # See mypy issue #5865
         def __init__(self):
@@ -52,7 +57,7 @@ def install_cache(
                 allowable_codes=allowable_codes,
                 allowable_methods=allowable_methods,
                 filter_fn=filter_fn,
-                old_data_on_error=old_data_on_error,
+                stale_if_error=stale_if_error,
                 **kwargs,
             )
 
@@ -125,8 +130,9 @@ def remove_expired_responses(expire_after: ExpirationTime = None):
     Args:
         expire_after: A new expiration time used to revalidate the cache
     """
-    if is_installed():
-        return requests.Session().remove_expired_responses(expire_after)  # type: ignore
+    session = requests.Session()
+    if isinstance(session, CachedSession):
+        session.remove_expired_responses(expire_after)
 
 
 def _patch_session_factory(session_factory: Type[OriginalSession] = CachedSession):
